<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr_BE">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Personnaliser Conky - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Lancement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Couleur0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Couleur1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Couleur2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Couleur3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Couleur4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Couleur5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Couleur6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Couleur7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Couleur8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Couleur9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="713"/>
        <source>Select Color</source>
        <translation>Sélectionner la couleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="819"/>
        <source>Permission Denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="820"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Impossible d’écrire dans le fichier: %1
Autorisations insuffisantes.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Write Error</source>
        <translation>Erreur d’écriture</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Cannot write to file: %1</source>
        <translation>Impossible d’écrire dans le fichier: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Backup Config File</source>
        <translation>Fichier de configuration de la sauvegarde</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Voulez-vous conserver le fichier d’origine?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="945"/>
        <source>Backed Up Config File</source>
        <translation>Fichier de configuration sauvegardé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="946"/>
        <source>The original configuration was backed up to %1</source>
        <translation>La configuration d’origine a été sauvegardée sur %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Backup Failed</source>
        <translation>Impossible de sauvegarder</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Failed to create a backup file.</source>
        <translation>Impossible de créer un fichier de sauvegarde.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Restore Failed</source>
        <translation>Impossible de restaurer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <source>Failed to restore from backup file.</source>
        <translation>Impossible d’effectuer la restauration à partir du fichier de sauvegarde.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Backup file does not exist.</source>
        <translation>Le fichier de sauvegarde n’existe pas.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1384"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1391"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1396"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1397"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1398"/>
        <source>Top Middle</source>
        <translation>En haut au milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1399"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1400"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1401"/>
        <source>Bottom Middle</source>
        <translation>En bas au milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1402"/>
        <source>Middle Left</source>
        <translation>Au milieu à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1403"/>
        <source>Middle Right</source>
        <translation>Au milieu à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1404"/>
        <source>Middle Middle</source>
        <translation>Milieu Milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1409"/>
        <source>Horizontal Gap</source>
        <translation>Écart horizontal</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1410"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Distance horizontale par rapport au bord de la fenêtre (en pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1422"/>
        <source>Vertical Gap</source>
        <translation>Écart vertical</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1423"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Distance verticale par rapport au bord de la fenêtre (en pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1435"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1438"/>
        <source>Desktop 1</source>
        <translation>Bureau 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1439"/>
        <source>All Desktops</source>
        <translation>Tous les bureaux</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1451"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1463"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>La largeur doit être supérieure à la taille du contenu de la fenêtre,
sinon ce paramètre n’aura aucun effet</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1467"/>
        <source>Minimum Width</source>
        <translation>Largeur minimale</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1482"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>La hauteur doit être supérieure à la taille du contenu de la fenêtre,
sinon ce paramètre n’aura aucun effet.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Minimum Height</source>
        <translation>Hauteur minimale</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1498"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Augmente la hauteur de la fenêtre en ajoutant des lignes vides à la fin du fichier de configuration Conky</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Height Padding</source>
        <translation>Marge intérieure en hauteur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1514"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1527"/>
        <source>Transparency Type</source>
        <translation>Type de transparence</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1532"/>
        <source>Opaque</source>
        <translation>Opaque</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1533"/>
        <source>Transparent</source>
        <translation>Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Pseudo-Transparent</source>
        <translation>Pseudo-Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1535"/>
        <source>Semi-Transparent</source>
        <translation>Semi-Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1540"/>
        <source>Opacity (%)</source>
        <translation>Opacité (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1541"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Opacité de la fenêtre

0 = Complètement transparent, 100 = Complètement opaque</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1555"/>
        <source>Background Color</source>
        <translation>Couleur d’arrière-plan</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1560"/>
        <source>Choose Color</source>
        <translation>Choisir la couleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1580"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Si vous réglez le type sur « Transparent », toute la fenêtre deviendra transparente (y compris les images). Utilisez « Pseudo-transparent » si vous souhaitez que les images restent opaques.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1590"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Si vous réglez le type sur « pseudo-transparent », la fenêtre deviendra transparente, mais elle aura une ombre. Vous pouvez désactiver l’ombre en configurant votre gestionnaire de fenêtres.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1601"/>
        <source>Transparency</source>
        <translation>Transparence</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1612"/>
        <source>Date Format</source>
        <translation>Format de la date</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1615"/>
        <source>Day</source>
        <translation>Jour</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1617"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1628"/>
        <source>Long</source>
        <translation>Long</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1618"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1629"/>
        <source>Short</source>
        <translation>Court</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1619"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nom abrégé, p.ex ma pour mardi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1626"/>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1630"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nom abrégé, p.ex oct pour octobre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1649"/>
        <source>Time Format</source>
        <translation>Format de l’heure</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1656"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1661"/>
        <source>12 Hour</source>
        <translation>12 heures</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1662"/>
        <source>24 Hour</source>
        <translation>24 heures</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1663"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1678"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Date &amp;&amp; Heure</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1691"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1699"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1702"/>
        <source>WiFi Network</source>
        <translation>Réseau WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1705"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1708"/>
        <source>Wired LAN Network</source>
        <translation>Réseau local câblé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1722"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="2037"/>
        <source>Select Background Color</source>
        <translation>Sélectionner la couleur du fond d’écran</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Personnaliser</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Total: 0 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Total: %1 conkies</source>
        <translation>Total: %1 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="601"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Affichage: %1 sur %2 conkies</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="550"/>
        <source>No Conky Selected</source>
        <translation>Aucun Conky sélectionné</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="552"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Sélectionner un conky dans la liste pour voir son aperçu</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>Preview image could not be loaded</source>
        <translation>L’image de prévisualisation n’a pas pu être chargée</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="574"/>
        <source>No preview image available</source>
        <translation>Aucune image de prévisualisation disponible</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="58"/>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>About...</source>
        <translation>À propos …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="270"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="268"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>Loading Conky configurations...</source>
        <translation>Chargement des configurations Conky …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>Configure conky search paths</source>
        <translation>Configurer les chemins de recherche de Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="192"/>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Refresh conky list</source>
        <translation>Rafraîchir la liste Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="196"/>
        <source>Start All</source>
        <translation>Tout démarrer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Start all enabled conkies</source>
        <translation>Démarrer tous les conkies activés</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="200"/>
        <source>Stop All</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="202"/>
        <source>Stop all running conkies</source>
        <translation>Arrêter tous les conkies en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="951"/>
        <location filename="../src/mainwindow.cpp" line="995"/>
        <source>Running</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="953"/>
        <location filename="../src/mainwindow.cpp" line="996"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <source>Search conky by name...</source>
        <translation>Rechercher Conky par le nom …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="212"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Rechercher des conkies par leur nom (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Display help</source>
        <translation>Afficher l’aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="433"/>
        <location filename="../src/mainwindow.cpp" line="607"/>
        <source>Copy Conky</source>
        <translation>Copier Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <location filename="../src/mainwindow.cpp" line="655"/>
        <source>Conky Copied</source>
        <translation>Conky copié</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="480"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky a été copié dans votre répertoire personnel pour être modifié:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Copy Failed</source>
        <translation>La copie a échoué</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Impossible de copier conky dans votre dossier personnel.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Delete Conky</source>
        <translation>Supprimer Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky a été copié dans votre dossier personnel pour que vous puissiez le personnaliser:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>Previews</source>
        <translation>Aperçus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Generate preview images for conkies</source>
        <translation>Générer des images d’aperçu pour les conkies</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <location filename="../src/mainwindow.cpp" line="643"/>
        <location filename="../src/mainwindow.cpp" line="949"/>
        <location filename="../src/mainwindow.cpp" line="994"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filtrer les conkies par état de fonctionnement ou emplacement</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="603"/>
        <source>Enter a name for the copy:</source>
        <translation>Entrez un nom pour la copie:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="430"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Pour pouvoir modifier et enregistrer un conky, vous devez d’abord le copier dans ~/.conky, où vous disposez des droits d’accès nécessaires.
Entrez un nom pour la copie.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="623"/>
        <source>Directory Exists</source>
        <translation>Le répertoire existe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="448"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Un conky nommé « %1 » existe déjà dans votre dossier personnel.
Voulez-vous le remplacer?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>Edit Conky</source>
        <translation>Modifier Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Ce fichier conky est en lecture seule et nécessite des privilèges d’administrateur•rice pour être modifié.
Voulez-vous le modifier avec des privilèges élevés?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="545"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Êtes-vous sûr•e de vouloir supprimer le fichier conky:
%1

Cette action ne peut pas être annulée.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Delete Failed</source>
        <translation>La suppression a échoué</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Impossible de supprimer le fichier conky:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Customize Conky</source>
        <translation>Personnaliser Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Ce fichier conky est en lecture seule et nécessite des privilèges d’administrateur•rice pour être personnalisé.
Souhaitez-vous le personnaliser avec des privilèges élevés?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Editor Error</source>
        <translation>Erreur de l’éditeur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Impossible de démarrer l’éditeur pour le fichier: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>About MX Conky</source>
        <translation>À propos de MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="850"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="851"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Interface graphique permettant de configurer Conky dans MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="854"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="856"/>
        <location filename="../src/mainwindow.cpp" line="868"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="857"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="879"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="910"/>
        <source>MX Conky Help</source>
        <translation>Aide MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="955"/>
        <location filename="../src/mainwindow.cpp" line="997"/>
        <source>Autostart</source>
        <translation>Démarrage automatique</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Générer un aperçu</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Générer des images d’aperçu pour</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Widget sélectionné</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Tous les widgets dont l’aperçu est manquant</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Tous les widgets (remplacer les images existantes)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Aucun conky n’est actuellement sélectionné</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Images de haute qualité (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Générer des images d’aperçu au format PNG au lieu du format JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Aucun élément</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Aucun widget Conky nécessite la génération d’un aperçu.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="151"/>
        <source>Missing Dependency</source>
        <translation>Dépendance manquante</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="152"/>
        <source>Preview generation requires the GraphicsMagick compatibility tools.
Please install the graphicsmagick-imagemagick-compat package to enable this feature.</source>
        <translation>La génération d’aperçus nécessite les outils de compatibilité GraphicsMagick.
Veuillez installer le paquet graphicsmagick-imagemagick-compat pour activer cette fonctionnalité.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="163"/>
        <source>Starting preview generation...</source>
        <translation>Lancement de la génération de l’aperçu …</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="167"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="206"/>
        <source>Generating preview for: %1</source>
        <translation>Génération de l’aperçu pour: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Génération de l’aperçu terminée! %1 aperçus générés.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="431"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="434"/>
        <source>Preview Generation Complete</source>
        <translation>Génération de l’aperçu terminée</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="435"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>%1 images d’aperçu ont été générées avec succès.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Choix du fichier de configuration de conky-manager</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Vous devez exécuter ce programme en tant qu’utilisateur•rice normal•e.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Sélectionner le répertoire Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>Paramètres MX Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Chemins de recherche</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Chemins de recherche Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Ajouter un chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Supprimer le chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Modifier le chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Paramètres du démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Démarrer Conky au démarrage du système</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Délai de démarrage (en secondes):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>